netapp_ontap.models.export_clients API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.export_clients`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ExportClientsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ExportClients object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `match: str GET POST PATCH`

    Client Match Hostname, IP Address, Netgroup, or Domain. You can specify the match as a string value in any of the following formats:

    - As a hostname; for instance, host1
    - As an IPv4 address; for instance, 10.1.12.24
    - As an IPv6 address; for instance, fd20:8b1e:b255:4071::100:1
    - As an IPv4 address with a subnet mask expressed as a number of bits; for instance, 10.1.12.0/24
    - As an IPv6 address with a subnet mask expressed as a number of bits; for instance, fd20:8b1e:b255:4071::/64
    - As an IPv4 address with a network mask; for instance, 10.1.16.0/255.255.255.0
    - As a netgroup, with the netgroup name preceded by the @ character; for instance, @eng
    - As a domain name preceded by the . character; for instance, .example.com

    Example: 0.0.0.0/0